"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import prodvana.proto.prodvana.delivery_module.config_pb2
import prodvana.proto.prodvana.delivery_module.object_pb2
import prodvana.proto.prodvana.version.source_metadata_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ConfigureDeliveryModuleReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_MODULE_CONFIG_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_METADATA_FIELD_NUMBER: builtins.int
    @property
    def delivery_module_config(self) -> prodvana.proto.prodvana.delivery_module.config_pb2.DeliveryModuleConfig: ...
    source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType
    @property
    def source_metadata(self) -> prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata: ...
    def __init__(
        self,
        *,
        delivery_module_config: prodvana.proto.prodvana.delivery_module.config_pb2.DeliveryModuleConfig | None = ...,
        source: prodvana.proto.prodvana.version.source_metadata_pb2.Source.ValueType = ...,
        source_metadata: prodvana.proto.prodvana.version.source_metadata_pb2.SourceMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delivery_module_config", b"delivery_module_config", "source_metadata", b"source_metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_module_config", b"delivery_module_config", "source", b"source", "source_metadata", b"source_metadata"]) -> None: ...

global___ConfigureDeliveryModuleReq = ConfigureDeliveryModuleReq

class ConfigureDeliveryModuleResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_MODULE_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    delivery_module_id: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        delivery_module_id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_module_id", b"delivery_module_id", "version", b"version"]) -> None: ...

global___ConfigureDeliveryModuleResp = ConfigureDeliveryModuleResp

class ValidateConfigureDeliveryModuleResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ValidateConfigureDeliveryModuleResp = ValidateConfigureDeliveryModuleResp

class ListDeliveryModulesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDeliveryModulesReq = ListDeliveryModulesReq

class ListDeliveryModulesResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_MODULES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def delivery_modules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.delivery_module.object_pb2.DeliveryModule]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        delivery_modules: collections.abc.Iterable[prodvana.proto.prodvana.delivery_module.object_pb2.DeliveryModule] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_modules", b"delivery_modules", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDeliveryModulesResp = ListDeliveryModulesResp

class GetDeliveryModuleReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_MODULE_FIELD_NUMBER: builtins.int
    delivery_module: builtins.str
    def __init__(
        self,
        *,
        delivery_module: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_module", b"delivery_module"]) -> None: ...

global___GetDeliveryModuleReq = GetDeliveryModuleReq

class GetDeliveryModuleResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_MODULE_FIELD_NUMBER: builtins.int
    @property
    def delivery_module(self) -> prodvana.proto.prodvana.delivery_module.object_pb2.DeliveryModule: ...
    def __init__(
        self,
        *,
        delivery_module: prodvana.proto.prodvana.delivery_module.object_pb2.DeliveryModule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["delivery_module", b"delivery_module"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_module", b"delivery_module"]) -> None: ...

global___GetDeliveryModuleResp = GetDeliveryModuleResp

class GetDeliveryModuleConfigReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELIVERY_MODULE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    delivery_module: builtins.str
    version: builtins.str
    """omit to get latest version"""
    def __init__(
        self,
        *,
        delivery_module: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delivery_module", b"delivery_module", "version", b"version"]) -> None: ...

global___GetDeliveryModuleConfigReq = GetDeliveryModuleConfigReq

class GetDeliveryModuleConfigResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> prodvana.proto.prodvana.delivery_module.config_pb2.DeliveryModuleConfig: ...
    version: builtins.str
    def __init__(
        self,
        *,
        config: prodvana.proto.prodvana.delivery_module.config_pb2.DeliveryModuleConfig | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "version", b"version"]) -> None: ...

global___GetDeliveryModuleConfigResp = GetDeliveryModuleConfigResp



import os
from typing import Any, Callable

import grpc
from grpc_interceptor import ClientCallDetails, ClientInterceptor

from prodvana.proto.prodvana.application import application_manager_pb2_grpc
from prodvana.proto.prodvana.desired_state import manager_pb2_grpc
from prodvana.proto.prodvana.organization import organization_manager_pb2_grpc
from prodvana.proto.prodvana.release_channel import release_channel_manager_pb2_grpc
from prodvana.proto.prodvana.service import service_manager_pb2_grpc


class AuthClientInterceptor(ClientInterceptor):
    def __init__(self) -> None:
        self.token = os.getenv("PVN_TOKEN")
        assert self.token, "PVN_TOKEN not set"
        self.header_value = f"Bearer {self.token}"

    def intercept(
        self,
        method: Callable[[Any, grpc.ClientCallDetails], Any],
        request_or_iterator: Any,
        call_details: grpc.ClientCallDetails,
    ) -> Any:
        metadata = []
        if call_details.metadata is not None:
            metadata = list(call_details.metadata)
        metadata.append(("authorization", self.header_value))
        new_details = ClientCallDetails(
            call_details.method,
            call_details.timeout,
            metadata,
            call_details.credentials,
            call_details.wait_for_ready,
            call_details.compression,
        )

        return method(request_or_iterator, new_details)


def make_channel() -> grpc.Channel:
    apiserver_addr = os.getenv("PVN_APISERVER_ADDR")
    assert apiserver_addr, "PVN_APISERVER_ADDR not set"
    server_name, _ = apiserver_addr.split(":")
    if server_name == "localhost":
        channel = grpc.insecure_channel(apiserver_addr)
    else:
        channel = grpc.secure_channel(apiserver_addr, grpc.ssl_channel_credentials())
    # use of an interceptor here instead of grpc.access_token_call_credentials is needed
    # because that function does not work with insecure_channel, see
    # https://groups.google.com/g/grpc-io/c/fFXbIXphudw
    channel = grpc.intercept_channel(channel, AuthClientInterceptor())
    return channel


class Client:
    def __init__(self, channel: grpc.Channel) -> None:
        self.application_manager = application_manager_pb2_grpc.ApplicationManagerStub(
            channel
        )
        self.organization_manager = (
            organization_manager_pb2_grpc.OrganizationManagerStub(channel)
        )
        self.release_channel_manager = (
            release_channel_manager_pb2_grpc.ReleaseChannelManagerStub(channel)
        )
        self.service_manager = service_manager_pb2_grpc.ServiceManagerStub(channel)
        self.desired_state_manager = manager_pb2_grpc.DesiredStateManagerStub(channel)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/delivery_module/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import task_pb2 as prodvana_dot_common__config_dot_task__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.prodvana.common_config import external_config_pb2 as prodvana_dot_common__config_dot_external__config__pb2
from prodvana.proto.prodvana.common_config import parameters_pb2 as prodvana_dot_common__config_dot_parameters__pb2
from prodvana.proto.prodvana.runtimes import runtimes_config_pb2 as prodvana_dot_runtimes_dot_runtimes__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%prodvana/delivery_module/config.proto\x12\x18prodvana.delivery_module\x1a\x17validate/validate.proto\x1a!prodvana/common_config/task.proto\x1a prodvana/common_config/env.proto\x1a,prodvana/common_config/external_config.proto\x1a\'prodvana/common_config/parameters.proto\x1a\'prodvana/runtimes/runtimes_config.proto\"\xb3\x02\n\x14\x44\x65liveryModuleConfig\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12\x39\n\x0btask_config\x18\x02 \x01(\x0b\x32\".prodvana.common_config.TaskConfigH\x00\x12\x41\n\x0f\x65xternal_config\x18\x03 \x01(\x0b\x32&.prodvana.common_config.ExternalConfigH\x00\x12N\n\nparameters\x18\x04 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinitionB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x42\x12\n\x0b\x65xec_config\x12\x03\xf8\x42\x01\"\x95\x01\n\x1c\x44\x65liveryModuleInstanceConfig\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12:\n\nparameters\x18\x03 \x03(\x0b\x32&.prodvana.common_config.ParameterValue\"\xbf\x03\n$CompiledDeliveryModuleInstanceConfig\x12\x42\n\ndefinition\x18\x01 \x01(\x0b\x32..prodvana.delivery_module.DeliveryModuleConfig\x12\x44\n\x11runtime_execution\x18\x02 \x01(\x0b\x32).prodvana.runtimes.RuntimeExecutionConfig\x12}\n\x03\x65nv\x18\x03 \x03(\x0b\x32G.prodvana.delivery_module.CompiledDeliveryModuleInstanceConfig.EnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x12@\n\x10parameter_values\x18\x04 \x03(\x0b\x32&.prodvana.common_config.ParameterValue\x1aL\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\x42TZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_moduleb\x06proto3')



_DELIVERYMODULECONFIG = DESCRIPTOR.message_types_by_name['DeliveryModuleConfig']
_DELIVERYMODULEINSTANCECONFIG = DESCRIPTOR.message_types_by_name['DeliveryModuleInstanceConfig']
_COMPILEDDELIVERYMODULEINSTANCECONFIG = DESCRIPTOR.message_types_by_name['CompiledDeliveryModuleInstanceConfig']
_COMPILEDDELIVERYMODULEINSTANCECONFIG_ENVENTRY = _COMPILEDDELIVERYMODULEINSTANCECONFIG.nested_types_by_name['EnvEntry']
DeliveryModuleConfig = _reflection.GeneratedProtocolMessageType('DeliveryModuleConfig', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERYMODULECONFIG,
  '__module__' : 'prodvana.delivery_module.config_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.DeliveryModuleConfig)
  })
_sym_db.RegisterMessage(DeliveryModuleConfig)

DeliveryModuleInstanceConfig = _reflection.GeneratedProtocolMessageType('DeliveryModuleInstanceConfig', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERYMODULEINSTANCECONFIG,
  '__module__' : 'prodvana.delivery_module.config_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.DeliveryModuleInstanceConfig)
  })
_sym_db.RegisterMessage(DeliveryModuleInstanceConfig)

CompiledDeliveryModuleInstanceConfig = _reflection.GeneratedProtocolMessageType('CompiledDeliveryModuleInstanceConfig', (_message.Message,), {

  'EnvEntry' : _reflection.GeneratedProtocolMessageType('EnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _COMPILEDDELIVERYMODULEINSTANCECONFIG_ENVENTRY,
    '__module__' : 'prodvana.delivery_module.config_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.delivery_module.CompiledDeliveryModuleInstanceConfig.EnvEntry)
    })
  ,
  'DESCRIPTOR' : _COMPILEDDELIVERYMODULEINSTANCECONFIG,
  '__module__' : 'prodvana.delivery_module.config_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.CompiledDeliveryModuleInstanceConfig)
  })
_sym_db.RegisterMessage(CompiledDeliveryModuleInstanceConfig)
_sym_db.RegisterMessage(CompiledDeliveryModuleInstanceConfig.EnvEntry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_module'
  _DELIVERYMODULECONFIG.oneofs_by_name['exec_config']._options = None
  _DELIVERYMODULECONFIG.oneofs_by_name['exec_config']._serialized_options = b'\370B\001'
  _DELIVERYMODULECONFIG.fields_by_name['name']._options = None
  _DELIVERYMODULECONFIG.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _DELIVERYMODULECONFIG.fields_by_name['parameters']._options = None
  _DELIVERYMODULECONFIG.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _DELIVERYMODULEINSTANCECONFIG.fields_by_name['name']._options = None
  _DELIVERYMODULEINSTANCECONFIG.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _COMPILEDDELIVERYMODULEINSTANCECONFIG_ENVENTRY._options = None
  _COMPILEDDELIVERYMODULEINSTANCECONFIG_ENVENTRY._serialized_options = b'8\001'
  _COMPILEDDELIVERYMODULEINSTANCECONFIG.fields_by_name['env']._options = None
  _COMPILEDDELIVERYMODULEINSTANCECONFIG.fields_by_name['env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _DELIVERYMODULECONFIG._serialized_start=290
  _DELIVERYMODULECONFIG._serialized_end=597
  _DELIVERYMODULEINSTANCECONFIG._serialized_start=600
  _DELIVERYMODULEINSTANCECONFIG._serialized_end=749
  _COMPILEDDELIVERYMODULEINSTANCECONFIG._serialized_start=752
  _COMPILEDDELIVERYMODULEINSTANCECONFIG._serialized_end=1199
  _COMPILEDDELIVERYMODULEINSTANCECONFIG_ENVENTRY._serialized_start=1123
  _COMPILEDDELIVERYMODULEINSTANCECONFIG_ENVENTRY._serialized_end=1199
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import prodvana.proto.prodvana.common_config.program_pb2
import prodvana.proto.prodvana.common_config.retry_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class TaskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROGRAM_FIELD_NUMBER: builtins.int
    RETRY_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def program(self) -> prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig: ...
    @property
    def retry_config(self) -> prodvana.proto.prodvana.common_config.retry_pb2.RetryConfig:
        """If not set, the task will not be retried once it starts executing once."""
    def __init__(
        self,
        *,
        program: prodvana.proto.prodvana.common_config.program_pb2.ProgramConfig | None = ...,
        retry_config: prodvana.proto.prodvana.common_config.retry_pb2.RetryConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["program", b"program", "retry_config", b"retry_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["program", b"program", "retry_config", b"retry_config"]) -> None: ...

global___TaskConfig = TaskConfig



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/pipelines/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.pipelines import pipelines_pb2 as prodvana_dot_pipelines_dot_pipelines__pb2
from prodvana.proto.prodvana.common_config import meta_pb2 as prodvana_dot_common__config_dot_meta__pb2
from prodvana.proto.prodvana.common_config import version_push_pb2 as prodvana_dot_common__config_dot_version__push__pb2
from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fprodvana/pipelines/object.proto\x12\x12prodvana.pipelines\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\"prodvana/pipelines/pipelines.proto\x1a!prodvana/common_config/meta.proto\x1a)prodvana/common_config/version_push.proto\x1a\x1aprodvana/object/meta.proto\"y\n\x10ServicePushParam\x12\x0f\n\x07service\x18\x01 \x01(\t\x12?\n\x0cversion_push\x18\x02 \x01(\x0b\x32).prodvana.common_config.VersionPushOption\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\"\xb6\x01\n\x13ServiceInstancePush\x12\x35\n\x10\x61pplication_meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12P\n\x15service_instance_meta\x18\x02 \x01(\x0b\x32\x31.prodvana.common_config.ServiceInstanceObjectMeta\x12\x16\n\x0etarget_version\x18\x03 \x01(\t\"\x9a\x01\n\nTaskStatus\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05state\x18\x02 \x01(\t\x12\x36\n\x12\x63reation_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x0f\n\rPipelineState\"\x9b\x01\n\x08Pipeline\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x32\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\".prodvana.pipelines.PipelineConfig\x12\x30\n\x05state\x18\x03 \x01(\x0b\x32!.prodvana.pipelines.PipelineState\"\x9a\x02\n\x11PipelineRunConfig\x12;\n\x0fpipeline_config\x18\x01 \x01(\x0b\x32\".prodvana.pipelines.PipelineConfig\x12\x41\n\x13service_push_params\x18\x02 \x03(\x0b\x32$.prodvana.pipelines.ServicePushParam\x12 \n\x18skip_rollback_validation\x18\x03 \x01(\x08\x12H\n\x17service_instance_pushes\x18\x04 \x03(\x0b\x32\'.prodvana.pipelines.ServiceInstancePush\x12\x19\n\x11skip_alert_checks\x18\x05 \x01(\x08\"\xbb\x02\n\x10PipelineRunState\x12\x36\n\x12\x63reation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05state\x18\x03 \x01(\t\x12\x10\n\x08terminal\x18\x04 \x01(\x08\x12\x35\n\rtask_statuses\x18\x05 \x03(\x0b\x32\x1e.prodvana.pipelines.TaskStatus\x12\x11\n\tlastActor\x18\x06 \x01(\t\x12\x11\n\tinitiator\x18\x07 \x01(\t\x12\x0e\n\x06reason\x18\x08 \x01(\t\x12\x0f\n\x07message\x18\t \x01(\t\x12\x15\n\rexternal_link\x18\n \x01(\t\"\xb6\x01\n\x0bPipelineRun\x12;\n\x04meta\x18\x01 \x01(\x0b\x32-.prodvana.common_config.PipelineRunObjectMeta\x12\x35\n\x06\x63onfig\x18\x02 \x01(\x0b\x32%.prodvana.pipelines.PipelineRunConfig\x12\x33\n\x05state\x18\x03 \x01(\x0b\x32$.prodvana.pipelines.PipelineRunStateBNZLgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pipelinesb\x06proto3')



_SERVICEPUSHPARAM = DESCRIPTOR.message_types_by_name['ServicePushParam']
_SERVICEINSTANCEPUSH = DESCRIPTOR.message_types_by_name['ServiceInstancePush']
_TASKSTATUS = DESCRIPTOR.message_types_by_name['TaskStatus']
_PIPELINESTATE = DESCRIPTOR.message_types_by_name['PipelineState']
_PIPELINE = DESCRIPTOR.message_types_by_name['Pipeline']
_PIPELINERUNCONFIG = DESCRIPTOR.message_types_by_name['PipelineRunConfig']
_PIPELINERUNSTATE = DESCRIPTOR.message_types_by_name['PipelineRunState']
_PIPELINERUN = DESCRIPTOR.message_types_by_name['PipelineRun']
ServicePushParam = _reflection.GeneratedProtocolMessageType('ServicePushParam', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEPUSHPARAM,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.ServicePushParam)
  })
_sym_db.RegisterMessage(ServicePushParam)

ServiceInstancePush = _reflection.GeneratedProtocolMessageType('ServiceInstancePush', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEINSTANCEPUSH,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.ServiceInstancePush)
  })
_sym_db.RegisterMessage(ServiceInstancePush)

TaskStatus = _reflection.GeneratedProtocolMessageType('TaskStatus', (_message.Message,), {
  'DESCRIPTOR' : _TASKSTATUS,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.TaskStatus)
  })
_sym_db.RegisterMessage(TaskStatus)

PipelineState = _reflection.GeneratedProtocolMessageType('PipelineState', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINESTATE,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.PipelineState)
  })
_sym_db.RegisterMessage(PipelineState)

Pipeline = _reflection.GeneratedProtocolMessageType('Pipeline', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINE,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.Pipeline)
  })
_sym_db.RegisterMessage(Pipeline)

PipelineRunConfig = _reflection.GeneratedProtocolMessageType('PipelineRunConfig', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINERUNCONFIG,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.PipelineRunConfig)
  })
_sym_db.RegisterMessage(PipelineRunConfig)

PipelineRunState = _reflection.GeneratedProtocolMessageType('PipelineRunState', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINERUNSTATE,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.PipelineRunState)
  })
_sym_db.RegisterMessage(PipelineRunState)

PipelineRun = _reflection.GeneratedProtocolMessageType('PipelineRun', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINERUN,
  '__module__' : 'prodvana.pipelines.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.pipelines.PipelineRun)
  })
_sym_db.RegisterMessage(PipelineRun)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/pipelines'
  _SERVICEPUSHPARAM._serialized_start=230
  _SERVICEPUSHPARAM._serialized_end=351
  _SERVICEINSTANCEPUSH._serialized_start=354
  _SERVICEINSTANCEPUSH._serialized_end=536
  _TASKSTATUS._serialized_start=539
  _TASKSTATUS._serialized_end=693
  _PIPELINESTATE._serialized_start=695
  _PIPELINESTATE._serialized_end=710
  _PIPELINE._serialized_start=713
  _PIPELINE._serialized_end=868
  _PIPELINERUNCONFIG._serialized_start=871
  _PIPELINERUNCONFIG._serialized_end=1153
  _PIPELINERUNSTATE._serialized_start=1156
  _PIPELINERUNSTATE._serialized_end=1471
  _PIPELINERUN._serialized_start=1474
  _PIPELINERUN._serialized_end=1656
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.delivery_module.manager_pb2

class DeliveryModuleManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ConfigureDeliveryModule: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_module.manager_pb2.ConfigureDeliveryModuleReq,
        prodvana.proto.prodvana.delivery_module.manager_pb2.ConfigureDeliveryModuleResp,
    ]
    ValidateConfigureDeliveryModule: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_module.manager_pb2.ConfigureDeliveryModuleReq,
        prodvana.proto.prodvana.delivery_module.manager_pb2.ValidateConfigureDeliveryModuleResp,
    ]
    ListDeliveryModules: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_module.manager_pb2.ListDeliveryModulesReq,
        prodvana.proto.prodvana.delivery_module.manager_pb2.ListDeliveryModulesResp,
    ]
    GetDeliveryModule: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleReq,
        prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleResp,
    ]
    GetDeliveryModuleConfig: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleConfigReq,
        prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleConfigResp,
    ]

class DeliveryModuleManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ConfigureDeliveryModule(
        self,
        request: prodvana.proto.prodvana.delivery_module.manager_pb2.ConfigureDeliveryModuleReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_module.manager_pb2.ConfigureDeliveryModuleResp: ...
    @abc.abstractmethod
    def ValidateConfigureDeliveryModule(
        self,
        request: prodvana.proto.prodvana.delivery_module.manager_pb2.ConfigureDeliveryModuleReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_module.manager_pb2.ValidateConfigureDeliveryModuleResp: ...
    @abc.abstractmethod
    def ListDeliveryModules(
        self,
        request: prodvana.proto.prodvana.delivery_module.manager_pb2.ListDeliveryModulesReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_module.manager_pb2.ListDeliveryModulesResp: ...
    @abc.abstractmethod
    def GetDeliveryModule(
        self,
        request: prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleResp: ...
    @abc.abstractmethod
    def GetDeliveryModuleConfig(
        self,
        request: prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleConfigReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.delivery_module.manager_pb2.GetDeliveryModuleConfigResp: ...

def add_DeliveryModuleManagerServicer_to_server(servicer: DeliveryModuleManagerServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class VersionPushOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[VersionPushOption._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: VersionPushOption._Type.ValueType  # 0
        PUSH_LATEST: VersionPushOption._Type.ValueType  # 1
        PUSH_VERSION: VersionPushOption._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    UNKNOWN: VersionPushOption.Type.ValueType  # 0
    PUSH_LATEST: VersionPushOption.Type.ValueType  # 1
    PUSH_VERSION: VersionPushOption.Type.ValueType  # 2

    TYPE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    type: global___VersionPushOption.Type.ValueType
    version: builtins.str
    """only valid if type = PUSH_VERSION"""
    def __init__(
        self,
        *,
        type: global___VersionPushOption.Type.ValueType = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "version", b"version"]) -> None: ...

global___VersionPushOption = VersionPushOption



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release_channel/release_channel_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.events import events_pb2 as prodvana_dot_events_dot_events__pb2
from prodvana.proto.prodvana.release_channel import object_pb2 as prodvana_dot_release__channel_dot_object__pb2
from prodvana.proto.prodvana.release_channel import release_channel_config_pb2 as prodvana_dot_release__channel_dot_release__channel__config__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6prodvana/release_channel/release_channel_manager.proto\x12\x18prodvana.release_channel\x1a\x1cgoogle/api/annotations.proto\x1a\x1cprodvana/events/events.proto\x1a%prodvana/release_channel/object.proto\x1a\x35prodvana/release_channel/release_channel_config.proto\x1a\x17validate/validate.proto\"\x8f\x01\n\x1a\x43onfigureReleaseChannelReq\x12G\n\x0frelease_channel\x18\x01 \x01(\x0b\x32..prodvana.release_channel.ReleaseChannelConfig\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63luster_name\x18\x03 \x01(\t\".\n\x1b\x43onfigureReleaseChannelResp\x12\x0f\n\x07version\x18\x01 \x01(\t\"2\n\x17\x44\x65leteReleaseChannelReq\x12\x17\n\x0frelease_channel\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteReleaseChannelResp\"-\n\x16ListReleaseChannelsReq\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\"]\n\x17ListReleaseChannelsResp\x12\x42\n\x10release_channels\x18\x01 \x03(\x0b\x32(.prodvana.release_channel.ReleaseChannel\"D\n\x14GetReleaseChannelReq\x12\x13\n\x0b\x61pplication\x18\x01 \x01(\t\x12\x17\n\x0frelease_channel\x18\x02 \x01(\t\"Z\n\x15GetReleaseChannelResp\x12\x41\n\x0frelease_channel\x18\x01 \x01(\x0b\x32(.prodvana.release_channel.ReleaseChannel\"\xa4\x01\n\x1aGetReleaseChannelEventsReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x0frelease_channel\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x1f\n\x17order_by_desc_timestamp\x18\x05 \x01(\x08\"^\n\x1bGetReleaseChannelEventsResp\x12&\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x16.prodvana.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe1\x08\n\x15ReleaseChannelManager\x12\xb1\x01\n\x17\x43onfigureReleaseChannel\x12\x34.prodvana.release_channel.ConfigureReleaseChannelReq\x1a\x35.prodvana.release_channel.ConfigureReleaseChannelResp\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/release-channels/configure:\x01*\x12\xb5\x01\n\x13ListReleaseChannels\x12\x30.prodvana.release_channel.ListReleaseChannelsReq\x1a\x31.prodvana.release_channel.ListReleaseChannelsResp\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/applications/{application=*}/release-channels\x12\xb6\x01\n\x14\x44\x65leteReleaseChannel\x12\x31.prodvana.release_channel.DeleteReleaseChannelReq\x1a\x32.prodvana.release_channel.DeleteReleaseChannelResp\"7\x82\xd3\xe4\x93\x02\x31*//v1/release-channels/{release_channel=*}/delete\x12~\n\x15ListReleaseChannelsV2\x12\x30.prodvana.release_channel.ListReleaseChannelsReq\x1a\x31.prodvana.release_channel.ListReleaseChannelsResp\"\x00\x12\xc3\x01\n\x11GetReleaseChannel\x12..prodvana.release_channel.GetReleaseChannelReq\x1a/.prodvana.release_channel.GetReleaseChannelResp\"M\x82\xd3\xe4\x93\x02G\x12\x45/v1/applications/{application=*}/release-channels/{release_channel=*}\x12\xdc\x01\n\x17GetReleaseChannelEvents\x12\x34.prodvana.release_channel.GetReleaseChannelEventsReq\x1a\x35.prodvana.release_channel.GetReleaseChannelEventsResp\"T\x82\xd3\xe4\x93\x02N\x12L/v1/applications/{application=*}/release-channels/{release_channel=*}/eventsBTZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channelb\x06proto3')



_CONFIGURERELEASECHANNELREQ = DESCRIPTOR.message_types_by_name['ConfigureReleaseChannelReq']
_CONFIGURERELEASECHANNELRESP = DESCRIPTOR.message_types_by_name['ConfigureReleaseChannelResp']
_DELETERELEASECHANNELREQ = DESCRIPTOR.message_types_by_name['DeleteReleaseChannelReq']
_DELETERELEASECHANNELRESP = DESCRIPTOR.message_types_by_name['DeleteReleaseChannelResp']
_LISTRELEASECHANNELSREQ = DESCRIPTOR.message_types_by_name['ListReleaseChannelsReq']
_LISTRELEASECHANNELSRESP = DESCRIPTOR.message_types_by_name['ListReleaseChannelsResp']
_GETRELEASECHANNELREQ = DESCRIPTOR.message_types_by_name['GetReleaseChannelReq']
_GETRELEASECHANNELRESP = DESCRIPTOR.message_types_by_name['GetReleaseChannelResp']
_GETRELEASECHANNELEVENTSREQ = DESCRIPTOR.message_types_by_name['GetReleaseChannelEventsReq']
_GETRELEASECHANNELEVENTSRESP = DESCRIPTOR.message_types_by_name['GetReleaseChannelEventsResp']
ConfigureReleaseChannelReq = _reflection.GeneratedProtocolMessageType('ConfigureReleaseChannelReq', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURERELEASECHANNELREQ,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ConfigureReleaseChannelReq)
  })
_sym_db.RegisterMessage(ConfigureReleaseChannelReq)

ConfigureReleaseChannelResp = _reflection.GeneratedProtocolMessageType('ConfigureReleaseChannelResp', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGURERELEASECHANNELRESP,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ConfigureReleaseChannelResp)
  })
_sym_db.RegisterMessage(ConfigureReleaseChannelResp)

DeleteReleaseChannelReq = _reflection.GeneratedProtocolMessageType('DeleteReleaseChannelReq', (_message.Message,), {
  'DESCRIPTOR' : _DELETERELEASECHANNELREQ,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.DeleteReleaseChannelReq)
  })
_sym_db.RegisterMessage(DeleteReleaseChannelReq)

DeleteReleaseChannelResp = _reflection.GeneratedProtocolMessageType('DeleteReleaseChannelResp', (_message.Message,), {
  'DESCRIPTOR' : _DELETERELEASECHANNELRESP,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.DeleteReleaseChannelResp)
  })
_sym_db.RegisterMessage(DeleteReleaseChannelResp)

ListReleaseChannelsReq = _reflection.GeneratedProtocolMessageType('ListReleaseChannelsReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTRELEASECHANNELSREQ,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ListReleaseChannelsReq)
  })
_sym_db.RegisterMessage(ListReleaseChannelsReq)

ListReleaseChannelsResp = _reflection.GeneratedProtocolMessageType('ListReleaseChannelsResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTRELEASECHANNELSRESP,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ListReleaseChannelsResp)
  })
_sym_db.RegisterMessage(ListReleaseChannelsResp)

GetReleaseChannelReq = _reflection.GeneratedProtocolMessageType('GetReleaseChannelReq', (_message.Message,), {
  'DESCRIPTOR' : _GETRELEASECHANNELREQ,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.GetReleaseChannelReq)
  })
_sym_db.RegisterMessage(GetReleaseChannelReq)

GetReleaseChannelResp = _reflection.GeneratedProtocolMessageType('GetReleaseChannelResp', (_message.Message,), {
  'DESCRIPTOR' : _GETRELEASECHANNELRESP,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.GetReleaseChannelResp)
  })
_sym_db.RegisterMessage(GetReleaseChannelResp)

GetReleaseChannelEventsReq = _reflection.GeneratedProtocolMessageType('GetReleaseChannelEventsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETRELEASECHANNELEVENTSREQ,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.GetReleaseChannelEventsReq)
  })
_sym_db.RegisterMessage(GetReleaseChannelEventsReq)

GetReleaseChannelEventsResp = _reflection.GeneratedProtocolMessageType('GetReleaseChannelEventsResp', (_message.Message,), {
  'DESCRIPTOR' : _GETRELEASECHANNELEVENTSRESP,
  '__module__' : 'prodvana.release_channel.release_channel_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.GetReleaseChannelEventsResp)
  })
_sym_db.RegisterMessage(GetReleaseChannelEventsResp)

_RELEASECHANNELMANAGER = DESCRIPTOR.services_by_name['ReleaseChannelManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channel'
  _GETRELEASECHANNELEVENTSREQ.fields_by_name['application']._options = None
  _GETRELEASECHANNELEVENTSREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETRELEASECHANNELEVENTSREQ.fields_by_name['release_channel']._options = None
  _GETRELEASECHANNELEVENTSREQ.fields_by_name['release_channel']._serialized_options = b'\372B\004r\002\020\001'
  _RELEASECHANNELMANAGER.methods_by_name['ConfigureReleaseChannel']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['ConfigureReleaseChannel']._serialized_options = b'\202\323\344\223\002#\"\036/v1/release-channels/configure:\001*'
  _RELEASECHANNELMANAGER.methods_by_name['ListReleaseChannels']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['ListReleaseChannels']._serialized_options = b'\202\323\344\223\0023\0221/v1/applications/{application=*}/release-channels'
  _RELEASECHANNELMANAGER.methods_by_name['DeleteReleaseChannel']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['DeleteReleaseChannel']._serialized_options = b'\202\323\344\223\0021*//v1/release-channels/{release_channel=*}/delete'
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannel']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannel']._serialized_options = b'\202\323\344\223\002G\022E/v1/applications/{application=*}/release-channels/{release_channel=*}'
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannelEvents']._options = None
  _RELEASECHANNELMANAGER.methods_by_name['GetReleaseChannelEvents']._serialized_options = b'\202\323\344\223\002N\022L/v1/applications/{application=*}/release-channels/{release_channel=*}/events'
  _CONFIGURERELEASECHANNELREQ._serialized_start=264
  _CONFIGURERELEASECHANNELREQ._serialized_end=407
  _CONFIGURERELEASECHANNELRESP._serialized_start=409
  _CONFIGURERELEASECHANNELRESP._serialized_end=455
  _DELETERELEASECHANNELREQ._serialized_start=457
  _DELETERELEASECHANNELREQ._serialized_end=507
  _DELETERELEASECHANNELRESP._serialized_start=509
  _DELETERELEASECHANNELRESP._serialized_end=535
  _LISTRELEASECHANNELSREQ._serialized_start=537
  _LISTRELEASECHANNELSREQ._serialized_end=582
  _LISTRELEASECHANNELSRESP._serialized_start=584
  _LISTRELEASECHANNELSRESP._serialized_end=677
  _GETRELEASECHANNELREQ._serialized_start=679
  _GETRELEASECHANNELREQ._serialized_end=747
  _GETRELEASECHANNELRESP._serialized_start=749
  _GETRELEASECHANNELRESP._serialized_end=839
  _GETRELEASECHANNELEVENTSREQ._serialized_start=842
  _GETRELEASECHANNELEVENTSREQ._serialized_end=1006
  _GETRELEASECHANNELEVENTSRESP._serialized_start=1008
  _GETRELEASECHANNELEVENTSRESP._serialized_end=1102
  _RELEASECHANNELMANAGER._serialized_start=1105
  _RELEASECHANNELMANAGER._serialized_end=2226
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/environment/clusters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import task_pb2 as prodvana_dot_common__config_dot_task__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#prodvana/environment/clusters.proto\x12\x14prodvana.environment\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\x1a!prodvana/common_config/task.proto\"\xe7\x04\n\x0b\x43lusterAuth\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61_cert\x18\x02 \x01(\t\x12\r\n\x05token\x18\x03 \x01(\t\x12\x17\n\x0fservice_account\x18\x04 \x01(\t\x12\x38\n\x03\x65\x63s\x18\x05 \x01(\x0b\x32).prodvana.environment.ClusterAuth.ECSAuthH\x00\x12M\n\x0egeneric_docker\x18\x07 \x01(\x0b\x32\x33.prodvana.environment.ClusterAuth.GenericDockerAuthH\x00\x12\x38\n\x03k8s\x18\x08 \x01(\x0b\x32).prodvana.environment.ClusterAuth.K8sAuthH\x00\x12\x16\n\x0ek8s_agent_auth\x18\x06 \x01(\x08\x1ao\n\x07\x45\x43SAuth\x12\x12\n\naccess_key\x18\x01 \x01(\t\x12\x12\n\nsecret_key\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x17\n\x0f\x61ssume_role_arn\x18\x04 \x01(\t\x12\x13\n\x0b\x63luster_arn\x18\x05 \x01(\t\x1a*\n\x11GenericDockerAuth\x12\x15\n\rproxy_runtime\x18\x01 \x01(\t\x1a\x86\x01\n\x07K8sAuth\x12J\n\tagent_env\x18\x01 \x03(\x0b\x32\x37.prodvana.environment.ClusterAuth.K8sAuth.AgentEnvEntry\x1a/\n\rAgentEnvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\nauth_oneof\"\xe9\x02\n\x07\x43luster\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x34\n\x06origin\x18\x03 \x01(\x0e\x32$.prodvana.environment.Cluster.Origin\x12/\n\x04\x61uth\x18\x04 \x01(\x0b\x32!.prodvana.environment.ClusterAuth\x12/\n\x04type\x18\x05 \x01(\x0e\x32!.prodvana.environment.ClusterType\x12\x33\n\x06\x63onfig\x18\x06 \x01(\x0b\x32#.prodvana.environment.ClusterConfig\x12<\n\x18last_heartbeat_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x06Origin\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08PRODVANA\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\xc6\x01\n\x11\x46\x61keClusterConfig\x12Z\n\x11\x63rashing_programs\x18\x01 \x03(\x0b\x32?.prodvana.environment.FakeClusterConfig.CrashingProgramPatterns\x1aU\n\x17\x43rashingProgramPatterns\x12\x13\n\x0bimage_regex\x18\x01 \x01(\t\x12\x11\n\tcmd_regex\x18\x02 \x01(\t\x12\x12\n\nlog_output\x18\x03 \x01(\t\"H\n\x14GenericDockerCommand\x12\x30\n\x04task\x18\x01 \x01(\x0b\x32\".prodvana.common_config.TaskConfig\"\x9e\x01\n\x1aGenericDockerClusterConfig\x12\x39\n\x05\x61pply\x18\x01 \x01(\x0b\x32*.prodvana.environment.GenericDockerCommand\x12\x45\n\x11get_current_state\x18\x02 \x01(\x0b\x32*.prodvana.environment.GenericDockerCommand\"\xc9\x0c\n\rClusterConfig\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\x17\n\x0f\x64isable_flagger\x18\x01 \x01(\x08\x12\x15\n\rdisable_istio\x18\x02 \x01(\x08\x12>\n\x08kubecost\x18\x03 \x01(\x0b\x32,.prodvana.environment.ClusterConfig.Kubecost\x12<\n\x07\x64\x61tadog\x18\x04 \x01(\x0b\x32+.prodvana.environment.ClusterConfig.Datadog\x12\x43\n\x0b\x61lb_ingress\x18\x06 \x01(\x0b\x32..prodvana.environment.ClusterConfig.ALBIngress\x12G\n\rargo_rollouts\x18\x07 \x01(\x0b\x32\x30.prodvana.environment.ClusterConfig.ArgoRollouts\x12\x43\n\x0bgke_ingress\x18\x08 \x01(\x0b\x32..prodvana.environment.ClusterConfig.GKEIngress\x12P\n\x18self_managed_gke_ingress\x18\x0b \x01(\x0b\x32..prodvana.environment.ClusterConfig.GKEIngress\x12I\n\x0e\x63loud_provider\x18\t \x01(\x0e\x32\x31.prodvana.environment.ClusterConfig.CloudProvider\x12\x37\n\x04\x66\x61ke\x18\n \x01(\x0b\x32\'.prodvana.environment.FakeClusterConfigH\x00\x12J\n\x0egeneric_docker\x18\x0c \x01(\x0b\x32\x30.prodvana.environment.GenericDockerClusterConfigH\x00\x1aH\n\x08Kubecost\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07managed\x18\x02 \x01(\x08\x12\x1a\n\x12kubecost_namespace\x18\x03 \x01(\t\x1a\x65\n\x07\x44\x61tadog\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07managed\x18\x02 \x01(\x08\x12\x19\n\x11\x64\x61tadog_namespace\x18\x03 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x04 \x01(\t\x12\x0c\n\x04site\x18\x05 \x01(\t\x1a\x62\n\nALBIngress\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1e\n\ringress_class\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12#\n\x1b\x64\x65\x66\x61ult_balancer_attributes\x18\x03 \x03(\t\x1a\xba\x03\n\x0c\x41rgoRollouts\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12T\n\ttemplates\x18\x02 \x03(\x0b\x32\x41.prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate\x1a\xc2\x02\n\x10\x41nalysisTemplate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x66\n\x0b\x61rg_mapping\x18\x02 \x03(\x0b\x32Q.prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgMappingEntry\x1a}\n\x0f\x41rgMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12Y\n\x05value\x18\x02 \x01(\x0e\x32J.prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgValue:\x02\x38\x01\"9\n\x08\x41rgValue\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVICE\x10\x01\x12\x13\n\x0fRELEASE_CHANNEL\x10\x02\x1a\x37\n\nGKEIngress\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x18\n\x10\x63ontainer_native\x18\x02 \x01(\x08\"T\n\rCloudProvider\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x45KS\x10\x01\x12\x07\n\x03GKE\x10\x02\x12\x07\n\x03\x41KS\x10\x03\x12\n\n\x06ONPREM\x10\x04\x12\x0f\n\x0bOTHER_CLOUD\x10\x05\x42\x0f\n\rcluster_oneofJ\x04\x08\x05\x10\x06R\x0f\x61ws_alb_ingress*J\n\x0b\x43lusterType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03K8S\x10\x01\x12\x07\n\x03\x45\x43S\x10\x02\x12\x08\n\x04\x46\x41KE\x10\x03\x12\x12\n\x0eGENERIC_DOCKER\x10\x04\x42PZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environmentb\x06proto3')

_CLUSTERTYPE = DESCRIPTOR.enum_types_by_name['ClusterType']
ClusterType = enum_type_wrapper.EnumTypeWrapper(_CLUSTERTYPE)
UNKNOWN = 0
K8S = 1
ECS = 2
FAKE = 3
GENERIC_DOCKER = 4


_CLUSTERAUTH = DESCRIPTOR.message_types_by_name['ClusterAuth']
_CLUSTERAUTH_ECSAUTH = _CLUSTERAUTH.nested_types_by_name['ECSAuth']
_CLUSTERAUTH_GENERICDOCKERAUTH = _CLUSTERAUTH.nested_types_by_name['GenericDockerAuth']
_CLUSTERAUTH_K8SAUTH = _CLUSTERAUTH.nested_types_by_name['K8sAuth']
_CLUSTERAUTH_K8SAUTH_AGENTENVENTRY = _CLUSTERAUTH_K8SAUTH.nested_types_by_name['AgentEnvEntry']
_CLUSTER = DESCRIPTOR.message_types_by_name['Cluster']
_FAKECLUSTERCONFIG = DESCRIPTOR.message_types_by_name['FakeClusterConfig']
_FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS = _FAKECLUSTERCONFIG.nested_types_by_name['CrashingProgramPatterns']
_GENERICDOCKERCOMMAND = DESCRIPTOR.message_types_by_name['GenericDockerCommand']
_GENERICDOCKERCLUSTERCONFIG = DESCRIPTOR.message_types_by_name['GenericDockerClusterConfig']
_CLUSTERCONFIG = DESCRIPTOR.message_types_by_name['ClusterConfig']
_CLUSTERCONFIG_KUBECOST = _CLUSTERCONFIG.nested_types_by_name['Kubecost']
_CLUSTERCONFIG_DATADOG = _CLUSTERCONFIG.nested_types_by_name['Datadog']
_CLUSTERCONFIG_ALBINGRESS = _CLUSTERCONFIG.nested_types_by_name['ALBIngress']
_CLUSTERCONFIG_ARGOROLLOUTS = _CLUSTERCONFIG.nested_types_by_name['ArgoRollouts']
_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE = _CLUSTERCONFIG_ARGOROLLOUTS.nested_types_by_name['AnalysisTemplate']
_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY = _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE.nested_types_by_name['ArgMappingEntry']
_CLUSTERCONFIG_GKEINGRESS = _CLUSTERCONFIG.nested_types_by_name['GKEIngress']
_CLUSTER_ORIGIN = _CLUSTER.enum_types_by_name['Origin']
_CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGVALUE = _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE.enum_types_by_name['ArgValue']
_CLUSTERCONFIG_CLOUDPROVIDER = _CLUSTERCONFIG.enum_types_by_name['CloudProvider']
ClusterAuth = _reflection.GeneratedProtocolMessageType('ClusterAuth', (_message.Message,), {

  'ECSAuth' : _reflection.GeneratedProtocolMessageType('ECSAuth', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERAUTH_ECSAUTH,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth.ECSAuth)
    })
  ,

  'GenericDockerAuth' : _reflection.GeneratedProtocolMessageType('GenericDockerAuth', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERAUTH_GENERICDOCKERAUTH,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth.GenericDockerAuth)
    })
  ,

  'K8sAuth' : _reflection.GeneratedProtocolMessageType('K8sAuth', (_message.Message,), {

    'AgentEnvEntry' : _reflection.GeneratedProtocolMessageType('AgentEnvEntry', (_message.Message,), {
      'DESCRIPTOR' : _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY,
      '__module__' : 'prodvana.environment.clusters_pb2'
      # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth.K8sAuth.AgentEnvEntry)
      })
    ,
    'DESCRIPTOR' : _CLUSTERAUTH_K8SAUTH,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth.K8sAuth)
    })
  ,
  'DESCRIPTOR' : _CLUSTERAUTH,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterAuth)
  })
_sym_db.RegisterMessage(ClusterAuth)
_sym_db.RegisterMessage(ClusterAuth.ECSAuth)
_sym_db.RegisterMessage(ClusterAuth.GenericDockerAuth)
_sym_db.RegisterMessage(ClusterAuth.K8sAuth)
_sym_db.RegisterMessage(ClusterAuth.K8sAuth.AgentEnvEntry)

Cluster = _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTER,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.Cluster)
  })
_sym_db.RegisterMessage(Cluster)

FakeClusterConfig = _reflection.GeneratedProtocolMessageType('FakeClusterConfig', (_message.Message,), {

  'CrashingProgramPatterns' : _reflection.GeneratedProtocolMessageType('CrashingProgramPatterns', (_message.Message,), {
    'DESCRIPTOR' : _FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.FakeClusterConfig.CrashingProgramPatterns)
    })
  ,
  'DESCRIPTOR' : _FAKECLUSTERCONFIG,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.FakeClusterConfig)
  })
_sym_db.RegisterMessage(FakeClusterConfig)
_sym_db.RegisterMessage(FakeClusterConfig.CrashingProgramPatterns)

GenericDockerCommand = _reflection.GeneratedProtocolMessageType('GenericDockerCommand', (_message.Message,), {
  'DESCRIPTOR' : _GENERICDOCKERCOMMAND,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.GenericDockerCommand)
  })
_sym_db.RegisterMessage(GenericDockerCommand)

GenericDockerClusterConfig = _reflection.GeneratedProtocolMessageType('GenericDockerClusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _GENERICDOCKERCLUSTERCONFIG,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.GenericDockerClusterConfig)
  })
_sym_db.RegisterMessage(GenericDockerClusterConfig)

ClusterConfig = _reflection.GeneratedProtocolMessageType('ClusterConfig', (_message.Message,), {

  'Kubecost' : _reflection.GeneratedProtocolMessageType('Kubecost', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERCONFIG_KUBECOST,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.Kubecost)
    })
  ,

  'Datadog' : _reflection.GeneratedProtocolMessageType('Datadog', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERCONFIG_DATADOG,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.Datadog)
    })
  ,

  'ALBIngress' : _reflection.GeneratedProtocolMessageType('ALBIngress', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERCONFIG_ALBINGRESS,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.ALBIngress)
    })
  ,

  'ArgoRollouts' : _reflection.GeneratedProtocolMessageType('ArgoRollouts', (_message.Message,), {

    'AnalysisTemplate' : _reflection.GeneratedProtocolMessageType('AnalysisTemplate', (_message.Message,), {

      'ArgMappingEntry' : _reflection.GeneratedProtocolMessageType('ArgMappingEntry', (_message.Message,), {
        'DESCRIPTOR' : _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY,
        '__module__' : 'prodvana.environment.clusters_pb2'
        # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgMappingEntry)
        })
      ,
      'DESCRIPTOR' : _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE,
      '__module__' : 'prodvana.environment.clusters_pb2'
      # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.ArgoRollouts.AnalysisTemplate)
      })
    ,
    'DESCRIPTOR' : _CLUSTERCONFIG_ARGOROLLOUTS,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.ArgoRollouts)
    })
  ,

  'GKEIngress' : _reflection.GeneratedProtocolMessageType('GKEIngress', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERCONFIG_GKEINGRESS,
    '__module__' : 'prodvana.environment.clusters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig.GKEIngress)
    })
  ,
  'DESCRIPTOR' : _CLUSTERCONFIG,
  '__module__' : 'prodvana.environment.clusters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.environment.ClusterConfig)
  })
_sym_db.RegisterMessage(ClusterConfig)
_sym_db.RegisterMessage(ClusterConfig.Kubecost)
_sym_db.RegisterMessage(ClusterConfig.Datadog)
_sym_db.RegisterMessage(ClusterConfig.ALBIngress)
_sym_db.RegisterMessage(ClusterConfig.ArgoRollouts)
_sym_db.RegisterMessage(ClusterConfig.ArgoRollouts.AnalysisTemplate)
_sym_db.RegisterMessage(ClusterConfig.ArgoRollouts.AnalysisTemplate.ArgMappingEntry)
_sym_db.RegisterMessage(ClusterConfig.GKEIngress)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/environment'
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._options = None
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._serialized_options = b'8\001'
  _CLUSTERCONFIG_ALBINGRESS.fields_by_name['ingress_class']._options = None
  _CLUSTERCONFIG_ALBINGRESS.fields_by_name['ingress_class']._serialized_options = b'\372B\004r\002\020\001'
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._options = None
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._serialized_options = b'8\001'
  _CLUSTERTYPE._serialized_start=3184
  _CLUSTERTYPE._serialized_end=3258
  _CLUSTERAUTH._serialized_start=155
  _CLUSTERAUTH._serialized_end=770
  _CLUSTERAUTH_ECSAUTH._serialized_start=464
  _CLUSTERAUTH_ECSAUTH._serialized_end=575
  _CLUSTERAUTH_GENERICDOCKERAUTH._serialized_start=577
  _CLUSTERAUTH_GENERICDOCKERAUTH._serialized_end=619
  _CLUSTERAUTH_K8SAUTH._serialized_start=622
  _CLUSTERAUTH_K8SAUTH._serialized_end=756
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._serialized_start=709
  _CLUSTERAUTH_K8SAUTH_AGENTENVENTRY._serialized_end=756
  _CLUSTER._serialized_start=773
  _CLUSTER._serialized_end=1134
  _CLUSTER_ORIGIN._serialized_start=1085
  _CLUSTER_ORIGIN._serialized_end=1134
  _FAKECLUSTERCONFIG._serialized_start=1137
  _FAKECLUSTERCONFIG._serialized_end=1335
  _FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS._serialized_start=1250
  _FAKECLUSTERCONFIG_CRASHINGPROGRAMPATTERNS._serialized_end=1335
  _GENERICDOCKERCOMMAND._serialized_start=1337
  _GENERICDOCKERCOMMAND._serialized_end=1409
  _GENERICDOCKERCLUSTERCONFIG._serialized_start=1412
  _GENERICDOCKERCLUSTERCONFIG._serialized_end=1570
  _CLUSTERCONFIG._serialized_start=1573
  _CLUSTERCONFIG._serialized_end=3182
  _CLUSTERCONFIG_KUBECOST._serialized_start=2279
  _CLUSTERCONFIG_KUBECOST._serialized_end=2351
  _CLUSTERCONFIG_DATADOG._serialized_start=2353
  _CLUSTERCONFIG_DATADOG._serialized_end=2454
  _CLUSTERCONFIG_ALBINGRESS._serialized_start=2456
  _CLUSTERCONFIG_ALBINGRESS._serialized_end=2554
  _CLUSTERCONFIG_ARGOROLLOUTS._serialized_start=2557
  _CLUSTERCONFIG_ARGOROLLOUTS._serialized_end=2999
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE._serialized_start=2677
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE._serialized_end=2999
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._serialized_start=2815
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGMAPPINGENTRY._serialized_end=2940
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGVALUE._serialized_start=2942
  _CLUSTERCONFIG_ARGOROLLOUTS_ANALYSISTEMPLATE_ARGVALUE._serialized_end=2999
  _CLUSTERCONFIG_GKEINGRESS._serialized_start=3001
  _CLUSTERCONFIG_GKEINGRESS._serialized_end=3056
  _CLUSTERCONFIG_CLOUDPROVIDER._serialized_start=3058
  _CLUSTERCONFIG_CLOUDPROVIDER._serialized_end=3142
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.common_config.meta_pb2
import prodvana.proto.prodvana.common_config.version_push_pb2
import prodvana.proto.prodvana.object.meta_pb2
import prodvana.proto.prodvana.pipelines.pipelines_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ServicePushParam(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    VERSION_PUSH_FIELD_NUMBER: builtins.int
    APPLICATION_FIELD_NUMBER: builtins.int
    service: builtins.str
    @property
    def version_push(self) -> prodvana.proto.prodvana.common_config.version_push_pb2.VersionPushOption: ...
    application: builtins.str
    def __init__(
        self,
        *,
        service: builtins.str = ...,
        version_push: prodvana.proto.prodvana.common_config.version_push_pb2.VersionPushOption | None = ...,
        application: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["version_push", b"version_push"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service", "version_push", b"version_push"]) -> None: ...

global___ServicePushParam = ServicePushParam

class ServiceInstancePush(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_META_FIELD_NUMBER: builtins.int
    SERVICE_INSTANCE_META_FIELD_NUMBER: builtins.int
    TARGET_VERSION_FIELD_NUMBER: builtins.int
    @property
    def application_meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    @property
    def service_instance_meta(self) -> prodvana.proto.prodvana.common_config.meta_pb2.ServiceInstanceObjectMeta:
        """service starting version stored in service_instance_meta"""
    target_version: builtins.str
    """TODO(naphat/rohit) store rollback target information here
    string rollback_target_version = 4;
    """
    def __init__(
        self,
        *,
        application_meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
        service_instance_meta: prodvana.proto.prodvana.common_config.meta_pb2.ServiceInstanceObjectMeta | None = ...,
        target_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application_meta", b"application_meta", "service_instance_meta", b"service_instance_meta"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_meta", b"application_meta", "service_instance_meta", b"service_instance_meta", "target_version", b"target_version"]) -> None: ...

global___ServiceInstancePush = ServiceInstancePush

class TaskStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
    id: builtins.int
    state: builtins.str
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        state: builtins.str = ...,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "last_update_timestamp", b"last_update_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "id", b"id", "last_update_timestamp", b"last_update_timestamp", "state", b"state"]) -> None: ...

global___TaskStatus = TaskStatus

class PipelineState(google.protobuf.message.Message):
    """TODO(naphat) put stuff here"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PipelineState = PipelineState

class Pipeline(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> prodvana.proto.prodvana.object.meta_pb2.ObjectMeta: ...
    @property
    def config(self) -> prodvana.proto.prodvana.pipelines.pipelines_pb2.PipelineConfig: ...
    @property
    def state(self) -> global___PipelineState: ...
    def __init__(
        self,
        *,
        meta: prodvana.proto.prodvana.object.meta_pb2.ObjectMeta | None = ...,
        config: prodvana.proto.prodvana.pipelines.pipelines_pb2.PipelineConfig | None = ...,
        state: global___PipelineState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state"]) -> None: ...

global___Pipeline = Pipeline

class PipelineRunConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_CONFIG_FIELD_NUMBER: builtins.int
    SERVICE_PUSH_PARAMS_FIELD_NUMBER: builtins.int
    SKIP_ROLLBACK_VALIDATION_FIELD_NUMBER: builtins.int
    SERVICE_INSTANCE_PUSHES_FIELD_NUMBER: builtins.int
    SKIP_ALERT_CHECKS_FIELD_NUMBER: builtins.int
    @property
    def pipeline_config(self) -> prodvana.proto.prodvana.pipelines.pipelines_pb2.PipelineConfig: ...
    @property
    def service_push_params(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServicePushParam]: ...
    skip_rollback_validation: builtins.bool
    @property
    def service_instance_pushes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceInstancePush]: ...
    skip_alert_checks: builtins.bool
    def __init__(
        self,
        *,
        pipeline_config: prodvana.proto.prodvana.pipelines.pipelines_pb2.PipelineConfig | None = ...,
        service_push_params: collections.abc.Iterable[global___ServicePushParam] | None = ...,
        skip_rollback_validation: builtins.bool = ...,
        service_instance_pushes: collections.abc.Iterable[global___ServiceInstancePush] | None = ...,
        skip_alert_checks: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline_config", b"pipeline_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline_config", b"pipeline_config", "service_instance_pushes", b"service_instance_pushes", "service_push_params", b"service_push_params", "skip_alert_checks", b"skip_alert_checks", "skip_rollback_validation", b"skip_rollback_validation"]) -> None: ...

global___PipelineRunConfig = PipelineRunConfig

class PipelineRunState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TERMINAL_FIELD_NUMBER: builtins.int
    TASK_STATUSES_FIELD_NUMBER: builtins.int
    LASTACTOR_FIELD_NUMBER: builtins.int
    INITIATOR_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    EXTERNAL_LINK_FIELD_NUMBER: builtins.int
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    state: builtins.str
    terminal: builtins.bool
    """if pipeline run is in a terminal state"""
    @property
    def task_statuses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TaskStatus]:
        """This will only be set when querying specifically about this pipeline run"""
    lastActor: builtins.str
    initiator: builtins.str
    reason: builtins.str
    message: builtins.str
    external_link: builtins.str
    def __init__(
        self,
        *,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        state: builtins.str = ...,
        terminal: builtins.bool = ...,
        task_statuses: collections.abc.Iterable[global___TaskStatus] | None = ...,
        lastActor: builtins.str = ...,
        initiator: builtins.str = ...,
        reason: builtins.str = ...,
        message: builtins.str = ...,
        external_link: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "last_update_timestamp", b"last_update_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "external_link", b"external_link", "initiator", b"initiator", "lastActor", b"lastActor", "last_update_timestamp", b"last_update_timestamp", "message", b"message", "reason", b"reason", "state", b"state", "task_statuses", b"task_statuses", "terminal", b"terminal"]) -> None: ...

global___PipelineRunState = PipelineRunState

class PipelineRun(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> prodvana.proto.prodvana.common_config.meta_pb2.PipelineRunObjectMeta: ...
    @property
    def config(self) -> global___PipelineRunConfig: ...
    @property
    def state(self) -> global___PipelineRunState: ...
    def __init__(
        self,
        *,
        meta: prodvana.proto.prodvana.common_config.meta_pb2.PipelineRunObjectMeta | None = ...,
        config: global___PipelineRunConfig | None = ...,
        state: global___PipelineRunState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "meta", b"meta", "state", b"state"]) -> None: ...

global___PipelineRun = PipelineRun



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/delivery_module/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from prodvana.proto.prodvana.delivery_module import object_pb2 as prodvana_dot_delivery__module_dot_object__pb2
from prodvana.proto.prodvana.delivery_module import config_pb2 as prodvana_dot_delivery__module_dot_config__pb2
from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&prodvana/delivery_module/manager.proto\x12\x18prodvana.delivery_module\x1a\x1cgoogle/api/annotations.proto\x1a%prodvana/delivery_module/object.proto\x1a%prodvana/delivery_module/config.proto\x1a&prodvana/version/source_metadata.proto\x1a\x17validate/validate.proto\"\xdb\x01\n\x1a\x43onfigureDeliveryModuleReq\x12X\n\x16\x64\x65livery_module_config\x18\x01 \x01(\x0b\x32..prodvana.delivery_module.DeliveryModuleConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12(\n\x06source\x18\x02 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x03 \x01(\x0b\x32 .prodvana.version.SourceMetadata\"J\n\x1b\x43onfigureDeliveryModuleResp\x12\x1a\n\x12\x64\x65livery_module_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"%\n#ValidateConfigureDeliveryModuleResp\"?\n\x16ListDeliveryModulesReq\x12\x12\n\npage_token\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\"v\n\x17ListDeliveryModulesResp\x12\x42\n\x10\x64\x65livery_modules\x18\x01 \x03(\x0b\x32(.prodvana.delivery_module.DeliveryModule\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"8\n\x14GetDeliveryModuleReq\x12 \n\x0f\x64\x65livery_module\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"Z\n\x15GetDeliveryModuleResp\x12\x41\n\x0f\x64\x65livery_module\x18\x01 \x01(\x0b\x32(.prodvana.delivery_module.DeliveryModule\"O\n\x1aGetDeliveryModuleConfigReq\x12 \n\x0f\x64\x65livery_module\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x07version\x18\x02 \x01(\t\"n\n\x1bGetDeliveryModuleConfigResp\x12>\n\x06\x63onfig\x18\x01 \x01(\x0b\x32..prodvana.delivery_module.DeliveryModuleConfig\x12\x0f\n\x07version\x18\x02 \x01(\t2\x9c\x07\n\x15\x44\x65liveryModuleManager\x12\xb1\x01\n\x17\x43onfigureDeliveryModule\x12\x34.prodvana.delivery_module.ConfigureDeliveryModuleReq\x1a\x35.prodvana.delivery_module.ConfigureDeliveryModuleResp\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/delivery_modules/configure:\x01*\x12\xca\x01\n\x1fValidateConfigureDeliveryModule\x12\x34.prodvana.delivery_module.ConfigureDeliveryModuleReq\x1a=.prodvana.delivery_module.ValidateConfigureDeliveryModuleResp\"2\x82\xd3\xe4\x93\x02,\"\'/v1/delivery_modules/configure/validate:\x01*\x12\x98\x01\n\x13ListDeliveryModules\x12\x30.prodvana.delivery_module.ListDeliveryModulesReq\x1a\x31.prodvana.delivery_module.ListDeliveryModulesResp\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/delivery_modules\x12\xa5\x01\n\x11GetDeliveryModule\x12..prodvana.delivery_module.GetDeliveryModuleReq\x1a/.prodvana.delivery_module.GetDeliveryModuleResp\"/\x82\xd3\xe4\x93\x02)\x12\'/v1/delivery_module/{delivery_module=*}\x12\xbe\x01\n\x17GetDeliveryModuleConfig\x12\x34.prodvana.delivery_module.GetDeliveryModuleConfigReq\x1a\x35.prodvana.delivery_module.GetDeliveryModuleConfigResp\"6\x82\xd3\xe4\x93\x02\x30\x12./v1/delivery_module/{delivery_module=*}/configBTZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_moduleb\x06proto3')



_CONFIGUREDELIVERYMODULEREQ = DESCRIPTOR.message_types_by_name['ConfigureDeliveryModuleReq']
_CONFIGUREDELIVERYMODULERESP = DESCRIPTOR.message_types_by_name['ConfigureDeliveryModuleResp']
_VALIDATECONFIGUREDELIVERYMODULERESP = DESCRIPTOR.message_types_by_name['ValidateConfigureDeliveryModuleResp']
_LISTDELIVERYMODULESREQ = DESCRIPTOR.message_types_by_name['ListDeliveryModulesReq']
_LISTDELIVERYMODULESRESP = DESCRIPTOR.message_types_by_name['ListDeliveryModulesResp']
_GETDELIVERYMODULEREQ = DESCRIPTOR.message_types_by_name['GetDeliveryModuleReq']
_GETDELIVERYMODULERESP = DESCRIPTOR.message_types_by_name['GetDeliveryModuleResp']
_GETDELIVERYMODULECONFIGREQ = DESCRIPTOR.message_types_by_name['GetDeliveryModuleConfigReq']
_GETDELIVERYMODULECONFIGRESP = DESCRIPTOR.message_types_by_name['GetDeliveryModuleConfigResp']
ConfigureDeliveryModuleReq = _reflection.GeneratedProtocolMessageType('ConfigureDeliveryModuleReq', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGUREDELIVERYMODULEREQ,
  '__module__' : 'prodvana.delivery_module.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.ConfigureDeliveryModuleReq)
  })
_sym_db.RegisterMessage(ConfigureDeliveryModuleReq)

ConfigureDeliveryModuleResp = _reflection.GeneratedProtocolMessageType('ConfigureDeliveryModuleResp', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGUREDELIVERYMODULERESP,
  '__module__' : 'prodvana.delivery_module.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.ConfigureDeliveryModuleResp)
  })
_sym_db.RegisterMessage(ConfigureDeliveryModuleResp)

ValidateConfigureDeliveryModuleResp = _reflection.GeneratedProtocolMessageType('ValidateConfigureDeliveryModuleResp', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATECONFIGUREDELIVERYMODULERESP,
  '__module__' : 'prodvana.delivery_module.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.ValidateConfigureDeliveryModuleResp)
  })
_sym_db.RegisterMessage(ValidateConfigureDeliveryModuleResp)

ListDeliveryModulesReq = _reflection.GeneratedProtocolMessageType('ListDeliveryModulesReq', (_message.Message,), {
  'DESCRIPTOR' : _LISTDELIVERYMODULESREQ,
  '__module__' : 'prodvana.delivery_module.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.ListDeliveryModulesReq)
  })
_sym_db.RegisterMessage(ListDeliveryModulesReq)

ListDeliveryModulesResp = _reflection.GeneratedProtocolMessageType('ListDeliveryModulesResp', (_message.Message,), {
  'DESCRIPTOR' : _LISTDELIVERYMODULESRESP,
  '__module__' : 'prodvana.delivery_module.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.ListDeliveryModulesResp)
  })
_sym_db.RegisterMessage(ListDeliveryModulesResp)

GetDeliveryModuleReq = _reflection.GeneratedProtocolMessageType('GetDeliveryModuleReq', (_message.Message,), {
  'DESCRIPTOR' : _GETDELIVERYMODULEREQ,
  '__module__' : 'prodvana.delivery_module.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.GetDeliveryModuleReq)
  })
_sym_db.RegisterMessage(GetDeliveryModuleReq)

GetDeliveryModuleResp = _reflection.GeneratedProtocolMessageType('GetDeliveryModuleResp', (_message.Message,), {
  'DESCRIPTOR' : _GETDELIVERYMODULERESP,
  '__module__' : 'prodvana.delivery_module.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.GetDeliveryModuleResp)
  })
_sym_db.RegisterMessage(GetDeliveryModuleResp)

GetDeliveryModuleConfigReq = _reflection.GeneratedProtocolMessageType('GetDeliveryModuleConfigReq', (_message.Message,), {
  'DESCRIPTOR' : _GETDELIVERYMODULECONFIGREQ,
  '__module__' : 'prodvana.delivery_module.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.GetDeliveryModuleConfigReq)
  })
_sym_db.RegisterMessage(GetDeliveryModuleConfigReq)

GetDeliveryModuleConfigResp = _reflection.GeneratedProtocolMessageType('GetDeliveryModuleConfigResp', (_message.Message,), {
  'DESCRIPTOR' : _GETDELIVERYMODULECONFIGRESP,
  '__module__' : 'prodvana.delivery_module.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.GetDeliveryModuleConfigResp)
  })
_sym_db.RegisterMessage(GetDeliveryModuleConfigResp)

_DELIVERYMODULEMANAGER = DESCRIPTOR.services_by_name['DeliveryModuleManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_module'
  _CONFIGUREDELIVERYMODULEREQ.fields_by_name['delivery_module_config']._options = None
  _CONFIGUREDELIVERYMODULEREQ.fields_by_name['delivery_module_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETDELIVERYMODULEREQ.fields_by_name['delivery_module']._options = None
  _GETDELIVERYMODULEREQ.fields_by_name['delivery_module']._serialized_options = b'\372B\004r\002\020\001'
  _GETDELIVERYMODULECONFIGREQ.fields_by_name['delivery_module']._options = None
  _GETDELIVERYMODULECONFIGREQ.fields_by_name['delivery_module']._serialized_options = b'\372B\004r\002\020\001'
  _DELIVERYMODULEMANAGER.methods_by_name['ConfigureDeliveryModule']._options = None
  _DELIVERYMODULEMANAGER.methods_by_name['ConfigureDeliveryModule']._serialized_options = b'\202\323\344\223\002#\"\036/v1/delivery_modules/configure:\001*'
  _DELIVERYMODULEMANAGER.methods_by_name['ValidateConfigureDeliveryModule']._options = None
  _DELIVERYMODULEMANAGER.methods_by_name['ValidateConfigureDeliveryModule']._serialized_options = b'\202\323\344\223\002,\"\'/v1/delivery_modules/configure/validate:\001*'
  _DELIVERYMODULEMANAGER.methods_by_name['ListDeliveryModules']._options = None
  _DELIVERYMODULEMANAGER.methods_by_name['ListDeliveryModules']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/delivery_modules'
  _DELIVERYMODULEMANAGER.methods_by_name['GetDeliveryModule']._options = None
  _DELIVERYMODULEMANAGER.methods_by_name['GetDeliveryModule']._serialized_options = b'\202\323\344\223\002)\022\'/v1/delivery_module/{delivery_module=*}'
  _DELIVERYMODULEMANAGER.methods_by_name['GetDeliveryModuleConfig']._options = None
  _DELIVERYMODULEMANAGER.methods_by_name['GetDeliveryModuleConfig']._serialized_options = b'\202\323\344\223\0020\022./v1/delivery_module/{delivery_module=*}/config'
  _CONFIGUREDELIVERYMODULEREQ._serialized_start=242
  _CONFIGUREDELIVERYMODULEREQ._serialized_end=461
  _CONFIGUREDELIVERYMODULERESP._serialized_start=463
  _CONFIGUREDELIVERYMODULERESP._serialized_end=537
  _VALIDATECONFIGUREDELIVERYMODULERESP._serialized_start=539
  _VALIDATECONFIGUREDELIVERYMODULERESP._serialized_end=576
  _LISTDELIVERYMODULESREQ._serialized_start=578
  _LISTDELIVERYMODULESREQ._serialized_end=641
  _LISTDELIVERYMODULESRESP._serialized_start=643
  _LISTDELIVERYMODULESRESP._serialized_end=761
  _GETDELIVERYMODULEREQ._serialized_start=763
  _GETDELIVERYMODULEREQ._serialized_end=819
  _GETDELIVERYMODULERESP._serialized_start=821
  _GETDELIVERYMODULERESP._serialized_end=911
  _GETDELIVERYMODULECONFIGREQ._serialized_start=913
  _GETDELIVERYMODULECONFIGREQ._serialized_end=992
  _GETDELIVERYMODULECONFIGRESP._serialized_start=994
  _GETDELIVERYMODULECONFIGRESP._serialized_end=1104
  _DELIVERYMODULEMANAGER._serialized_start=1107
  _DELIVERYMODULEMANAGER._serialized_end=2031
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/delivery_module/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.delivery_module import config_pb2 as prodvana_dot_delivery__module_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%prodvana/delivery_module/object.proto\x12\x18prodvana.delivery_module\x1a\x1aprodvana/object/meta.proto\x1a%prodvana/delivery_module/config.proto\"\xb9\x01\n\x0e\x44\x65liveryModule\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12>\n\x06\x63onfig\x18\x02 \x01(\x0b\x32..prodvana.delivery_module.DeliveryModuleConfig\x12<\n\x05state\x18\x03 \x01(\x0b\x32-.prodvana.delivery_module.DeliveryModuleState\"\x15\n\x13\x44\x65liveryModuleStateBTZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_moduleb\x06proto3')



_DELIVERYMODULE = DESCRIPTOR.message_types_by_name['DeliveryModule']
_DELIVERYMODULESTATE = DESCRIPTOR.message_types_by_name['DeliveryModuleState']
DeliveryModule = _reflection.GeneratedProtocolMessageType('DeliveryModule', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERYMODULE,
  '__module__' : 'prodvana.delivery_module.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.DeliveryModule)
  })
_sym_db.RegisterMessage(DeliveryModule)

DeliveryModuleState = _reflection.GeneratedProtocolMessageType('DeliveryModuleState', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERYMODULESTATE,
  '__module__' : 'prodvana.delivery_module.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.delivery_module.DeliveryModuleState)
  })
_sym_db.RegisterMessage(DeliveryModuleState)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/delivery_module'
  _DELIVERYMODULE._serialized_start=135
  _DELIVERYMODULE._serialized_end=320
  _DELIVERYMODULESTATE._serialized_start=322
  _DELIVERYMODULESTATE._serialized_end=343
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/task.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2
from prodvana.proto.prodvana.common_config import retry_pb2 as prodvana_dot_common__config_dot_retry__pb2
from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/common_config/task.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\x1a\"prodvana/common_config/retry.proto\x1a$prodvana/common_config/program.proto\"\x89\x01\n\nTaskConfig\x12@\n\x07program\x18\x01 \x01(\x0b\x32%.prodvana.common_config.ProgramConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x39\n\x0cretry_config\x18\x02 \x01(\x0b\x32#.prodvana.common_config.RetryConfigBRZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')



_TASKCONFIG = DESCRIPTOR.message_types_by_name['TaskConfig']
TaskConfig = _reflection.GeneratedProtocolMessageType('TaskConfig', (_message.Message,), {
  'DESCRIPTOR' : _TASKCONFIG,
  '__module__' : 'prodvana.common_config.task_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.TaskConfig)
  })
_sym_db.RegisterMessage(TaskConfig)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _TASKCONFIG.fields_by_name['program']._options = None
  _TASKCONFIG.fields_by_name['program']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TASKCONFIG._serialized_start=161
  _TASKCONFIG._serialized_end=298
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/version_push.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)prodvana/common_config/version_push.proto\x12\x16prodvana.common_config\"\x9a\x01\n\x11VersionPushOption\x12<\n\x04type\x18\x01 \x01(\x0e\x32..prodvana.common_config.VersionPushOption.Type\x12\x0f\n\x07version\x18\x02 \x01(\t\"6\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0bPUSH_LATEST\x10\x01\x12\x10\n\x0cPUSH_VERSION\x10\x02\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')



_VERSIONPUSHOPTION = DESCRIPTOR.message_types_by_name['VersionPushOption']
_VERSIONPUSHOPTION_TYPE = _VERSIONPUSHOPTION.enum_types_by_name['Type']
VersionPushOption = _reflection.GeneratedProtocolMessageType('VersionPushOption', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONPUSHOPTION,
  '__module__' : 'prodvana.common_config.version_push_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.VersionPushOption)
  })
_sym_db.RegisterMessage(VersionPushOption)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _VERSIONPUSHOPTION._serialized_start=70
  _VERSIONPUSHOPTION._serialized_end=224
  _VERSIONPUSHOPTION_TYPE._serialized_start=170
  _VERSIONPUSHOPTION_TYPE._serialized_end=224
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from prodvana.proto.prodvana.delivery_module import manager_pb2 as prodvana_dot_delivery__module_dot_manager__pb2


class DeliveryModuleManagerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ConfigureDeliveryModule = channel.unary_unary(
                '/prodvana.delivery_module.DeliveryModuleManager/ConfigureDeliveryModule',
                request_serializer=prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleResp.FromString,
                )
        self.ValidateConfigureDeliveryModule = channel.unary_unary(
                '/prodvana.delivery_module.DeliveryModuleManager/ValidateConfigureDeliveryModule',
                request_serializer=prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.ValidateConfigureDeliveryModuleResp.FromString,
                )
        self.ListDeliveryModules = channel.unary_unary(
                '/prodvana.delivery_module.DeliveryModuleManager/ListDeliveryModules',
                request_serializer=prodvana_dot_delivery__module_dot_manager__pb2.ListDeliveryModulesReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.ListDeliveryModulesResp.FromString,
                )
        self.GetDeliveryModule = channel.unary_unary(
                '/prodvana.delivery_module.DeliveryModuleManager/GetDeliveryModule',
                request_serializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleResp.FromString,
                )
        self.GetDeliveryModuleConfig = channel.unary_unary(
                '/prodvana.delivery_module.DeliveryModuleManager/GetDeliveryModuleConfig',
                request_serializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleConfigReq.SerializeToString,
                response_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleConfigResp.FromString,
                )


class DeliveryModuleManagerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ConfigureDeliveryModule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateConfigureDeliveryModule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeliveryModules(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeliveryModule(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDeliveryModuleConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeliveryModuleManagerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ConfigureDeliveryModule': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureDeliveryModule,
                    request_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleReq.FromString,
                    response_serializer=prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleResp.SerializeToString,
            ),
            'ValidateConfigureDeliveryModule': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateConfigureDeliveryModule,
                    request_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleReq.FromString,
                    response_serializer=prodvana_dot_delivery__module_dot_manager__pb2.ValidateConfigureDeliveryModuleResp.SerializeToString,
            ),
            'ListDeliveryModules': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeliveryModules,
                    request_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.ListDeliveryModulesReq.FromString,
                    response_serializer=prodvana_dot_delivery__module_dot_manager__pb2.ListDeliveryModulesResp.SerializeToString,
            ),
            'GetDeliveryModule': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeliveryModule,
                    request_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleReq.FromString,
                    response_serializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleResp.SerializeToString,
            ),
            'GetDeliveryModuleConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDeliveryModuleConfig,
                    request_deserializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleConfigReq.FromString,
                    response_serializer=prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleConfigResp.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'prodvana.delivery_module.DeliveryModuleManager', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeliveryModuleManager(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ConfigureDeliveryModule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_module.DeliveryModuleManager/ConfigureDeliveryModule',
            prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleReq.SerializeToString,
            prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateConfigureDeliveryModule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_module.DeliveryModuleManager/ValidateConfigureDeliveryModule',
            prodvana_dot_delivery__module_dot_manager__pb2.ConfigureDeliveryModuleReq.SerializeToString,
            prodvana_dot_delivery__module_dot_manager__pb2.ValidateConfigureDeliveryModuleResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeliveryModules(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_module.DeliveryModuleManager/ListDeliveryModules',
            prodvana_dot_delivery__module_dot_manager__pb2.ListDeliveryModulesReq.SerializeToString,
            prodvana_dot_delivery__module_dot_manager__pb2.ListDeliveryModulesResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeliveryModule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_module.DeliveryModuleManager/GetDeliveryModule',
            prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleReq.SerializeToString,
            prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDeliveryModuleConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/prodvana.delivery_module.DeliveryModuleManager/GetDeliveryModuleConfig',
            prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleConfigReq.SerializeToString,
            prodvana_dot_delivery__module_dot_manager__pb2.GetDeliveryModuleConfigResp.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
